import { take, switchMap } from 'rxjs/operators';
import { Subject, Subscription, lastValueFrom, fromEvent, race, firstValueFrom } from 'rxjs';
import * as i0 from '@angular/core';
import { EventEmitter, Component, ChangeDetectionStrategy, ViewEncapsulation, Optional, Output, HostListener, Inject, HostBinding, Input, Directive, ViewChild, createEnvironmentInjector, createComponent, Injectable, NgModule } from '@angular/core';
import { style, animate, query, group, transition, trigger } from '@angular/animations';
import * as i3 from '@angular/common';
import { DOCUMENT, CommonModule } from '@angular/common';
import * as i1 from '@bravobit/bb-foundation';
import * as i1$1 from '@bravobit/bb-foundation/elements';
import { BbButton, ElementsModule } from '@bravobit/bb-foundation/elements';
import * as i5 from '@bravobit/bb-foundation/utils';
import * as i9 from '@bravobit/bb-foundation/localize';
import { LocalizeModule } from '@bravobit/bb-foundation/localize';

class BbDialogRef {
    constructor() {
        // Data.
        this._afterClosed$ = new Subject();
        this._overlayClicked$ = new Subject();
    }
    get afterClosed() {
        return this._afterClosed$.pipe(take(1));
    }
    get overlayClicked() {
        return this._overlayClicked$.pipe(take(1));
    }
    onOverlayClicked() {
        this._overlayClicked$.next();
    }
    close(result) {
        this._afterClosed$.next(result);
    }
}

class BbDialogConfig {
}
class DialogConfig {
}

const bbDialogOverlayAnimation = trigger('bbDialogOverlayAnimation', [
    transition(':enter, * => open', [
        group([
            query('.bb-dialog-overlay-backdrop', [
                style({ opacity: 0 }),
                animate('240ms cubic-bezier(0, 0, 0.2, 1)', style({ opacity: 1 }))
            ]),
            query('.bb-dialog-modal', [
                style({ opacity: 0, transform: 'scale(0.98)' }),
                animate('200ms cubic-bezier(0, 0, 0.2, 1)', style({ opacity: 1, transform: 'none' }))
            ])
        ])
    ]),
    transition(':leave, * => close', [
        group([
            query('.bb-dialog-modal', [
                animate('200ms cubic-bezier(0, 0, 0.2, 1)', style({ opacity: 0, transform: 'scale(0.98)' }))
            ]),
            query('.bb-dialog-overlay-backdrop', [
                animate('240ms cubic-bezier(0, 0, 0.2, 1)', style({ opacity: 0 }))
            ])
        ])
    ])
]);

class BbDialogOverlay {
    constructor(_elementRef, _changeDetection, _config) {
        this._elementRef = _elementRef;
        this._changeDetection = _changeDetection;
        this._config = _config;
        // Readonly data.
        this.disableOverlayAnimations = this._config?.disableOverlayAnimations ?? false;
        // Outputs.
        this.closeRequested = new EventEmitter();
        // State.
        this.state = 'open';
        this._closed$ = new Subject();
        // Subscriptions.
        this._subscription = new Subscription();
    }
    ngOnInit() {
        this.listenForClicks();
    }
    ngOnDestroy() {
        this._subscription?.unsubscribe();
    }
    onKeyEvent(event) {
        if (event?.key === 'Escape') {
            this.closeRequested.emit();
        }
    }
    onAnimationDone(event) {
        // Check if the dialog is being destroyed.
        if (!['close'].includes(event?.toState)) {
            return;
        }
        this._closed$.next();
        this._closed$.complete();
    }
    close() {
        // We need change detection to run
        // here else it won't close in all scenario's.
        this.state = 'close';
        this._changeDetection.markForCheck();
        // Listen for the closed trigger.
        const observable$ = this._closed$.pipe(take(1));
        return lastValueFrom(observable$);
    }
    listenForClicks() {
        const element = this._elementRef?.nativeElement ?? null;
        if (!element) {
            return;
        }
        const mouseDown$ = fromEvent(element, 'mousedown');
        const touchStart$ = fromEvent(element, 'touchstart');
        const start$ = race([mouseDown$, touchStart$]);
        const mouseUp$ = fromEvent(element, 'mouseup');
        const touchEnd$ = fromEvent(element, 'touchend');
        const end$ = race([mouseUp$, touchEnd$]);
        const clicks$ = start$.pipe(switchMap(() => end$));
        const subscription = clicks$.subscribe(() => this.closeRequested.next());
        this._subscription.add(subscription);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbDialogOverlay, deps: [{ token: i0.ElementRef }, { token: i0.ChangeDetectorRef }, { token: DialogConfig, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.0.6", type: BbDialogOverlay, selector: "bb-dialog-overlay", outputs: { closeRequested: "closeRequested" }, host: { listeners: { "window:keyup": "onKeyEvent($event)", "@bbDialogOverlayAnimation.done": "onAnimationDone($event)" }, properties: { "@bbDialogOverlayAnimation": "state", "@.disabled": "disableOverlayAnimations" }, classAttribute: "bb-dialog-overlay" }, ngImport: i0, template: "<div class=\"bb-dialog-overlay-backdrop\"></div>\n\n<ng-content select=\"[bb-dialog-modal]\"></ng-content>\n", styles: [".bb-dialog-overlay,.bb-dialog-overlay-backdrop{inset:0;display:flex;z-index:1000;position:fixed;flex-direction:column}.bb-dialog-overlay{padding:20px}.bb-dialog-overlay-backdrop{will-change:opacity;background-color:#1119}.bb-dialog-overlay-component{z-index:1001;display:block;position:relative}\n"], animations: [bbDialogOverlayAnimation], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbDialogOverlay, decorators: [{
            type: Component,
            args: [{ selector: 'bb-dialog-overlay', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, preserveWhitespaces: false, host: {
                        'class': 'bb-dialog-overlay',
                        '[@bbDialogOverlayAnimation]': 'state',
                        '[@.disabled]': 'disableOverlayAnimations'
                    }, animations: [bbDialogOverlayAnimation], template: "<div class=\"bb-dialog-overlay-backdrop\"></div>\n\n<ng-content select=\"[bb-dialog-modal]\"></ng-content>\n", styles: [".bb-dialog-overlay,.bb-dialog-overlay-backdrop{inset:0;display:flex;z-index:1000;position:fixed;flex-direction:column}.bb-dialog-overlay{padding:20px}.bb-dialog-overlay-backdrop{will-change:opacity;background-color:#1119}.bb-dialog-overlay-component{z-index:1001;display:block;position:relative}\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: DialogConfig, decorators: [{
                    type: Optional
                }] }], propDecorators: { closeRequested: [{
                type: Output
            }], onKeyEvent: [{
                type: HostListener,
                args: ['window:keyup', ['$event']]
            }], onAnimationDone: [{
                type: HostListener,
                args: ['@bbDialogOverlayAnimation.done', ['$event']]
            }] } });

class BbDialogModal {
    onOverlayClickedEvent(event) {
        event.stopPropagation();
    }
    constructor(_patch, _renderer, _document) {
        this._patch = _patch;
        this._renderer = _renderer;
        this._document = _document;
        // Styling.
        this.maxWidth = '420px';
    }
    ngOnInit() {
        this._patch.mobileVerticalHeight();
        this.allowGlobalOverflow(false);
    }
    ngOnDestroy() {
        this.allowGlobalOverflow(true);
    }
    allowGlobalOverflow(allow) {
        const element = this._document?.body ?? null;
        if (!element) {
            return;
        }
        allow
            ? this._renderer.removeStyle(element, 'overflow')
            : this._renderer.setStyle(element, 'overflow', 'hidden');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbDialogModal, deps: [{ token: i1.Patch }, { token: i0.Renderer2 }, { token: DOCUMENT, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.0.6", type: BbDialogModal, selector: "[bb-dialog-modal]", inputs: { maxWidth: "maxWidth" }, host: { attributes: { "role": "dialog" }, listeners: { "click": "onOverlayClickedEvent($event)", "touchstart": "onOverlayClickedEvent($event)", "touchend": "onOverlayClickedEvent($event)", "mouseup": "onOverlayClickedEvent($event)", "mousedown": "onOverlayClickedEvent($event)" }, properties: { "style.max-width": "this.maxWidth" }, classAttribute: "bb-dialog-modal" }, ngImport: i0, template: "<ng-content select=\"[bb-dialog-header]\">\n\n</ng-content>\n\n<div class=\"bb-dialog-modal-body\">\n    <ng-content></ng-content>\n</div>\n\n<ng-content select=\"[bb-dialog-actions]\">\n\n</ng-content>\n", styles: [".bb-dialog-modal{width:100%;margin:auto;z-index:1001;display:flex;max-width:420px;border-radius:4px;position:relative;flex-direction:column;background-color:#fff;will-change:opacity,transform;max-height:calc(var(--vh, 1vh) * 100 - 40px)}.bb-dialog-modal-body{padding:20px;color:#738694;font-size:13px;overflow-y:auto;line-height:1.4;background-color:#f1f3f6}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbDialogModal, decorators: [{
            type: Component,
            args: [{ selector: '[bb-dialog-modal]', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, preserveWhitespaces: false, host: {
                        'class': 'bb-dialog-modal',
                        'role': 'dialog'
                    }, template: "<ng-content select=\"[bb-dialog-header]\">\n\n</ng-content>\n\n<div class=\"bb-dialog-modal-body\">\n    <ng-content></ng-content>\n</div>\n\n<ng-content select=\"[bb-dialog-actions]\">\n\n</ng-content>\n", styles: [".bb-dialog-modal{width:100%;margin:auto;z-index:1001;display:flex;max-width:420px;border-radius:4px;position:relative;flex-direction:column;background-color:#fff;will-change:opacity,transform;max-height:calc(var(--vh, 1vh) * 100 - 40px)}.bb-dialog-modal-body{padding:20px;color:#738694;font-size:13px;overflow-y:auto;line-height:1.4;background-color:#f1f3f6}\n"] }]
        }], ctorParameters: () => [{ type: i1.Patch }, { type: i0.Renderer2 }, { type: Document, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [DOCUMENT]
                }] }], propDecorators: { maxWidth: [{
                type: HostBinding,
                args: ['style.max-width']
            }, {
                type: Input
            }], onOverlayClickedEvent: [{
                type: HostListener,
                args: ['click', ['$event']]
            }, {
                type: HostListener,
                args: ['touchstart', ['$event']]
            }, {
                type: HostListener,
                args: ['touchend', ['$event']]
            }, {
                type: HostListener,
                args: ['mouseup', ['$event']]
            }, {
                type: HostListener,
                args: ['mousedown', ['$event']]
            }] } });

class BbDialogHeader {
    constructor() {
        // Outputs.
        this.closeRequested = new EventEmitter();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbDialogHeader, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.0.6", type: BbDialogHeader, selector: "[bb-dialog-header]", outputs: { closeRequested: "closeRequested" }, host: { classAttribute: "bb-dialog-header" }, ngImport: i0, template: "<div class=\"bb-dialog-header-row\">\n    <div class=\"bb-dialog-header-content\">\n        <ng-content></ng-content>\n    </div>\n\n    <button *ngIf=\"closeRequested?.observed\"\n            (click)=\"closeRequested?.emit()\"\n            type=\"button\"\n            class=\"bb-dialog-header-close\">\n    </button>\n</div>\n\n<nav class=\"bb-dialog-header-navigation\">\n    <ng-content select=\"[bb-dialog-link]\"></ng-content>\n</nav>\n", styles: [".bb-dialog-header{display:flex;min-height:60px;flex-direction:column;justify-content:center;background-color:#fff;border-top-left-radius:4px;border-top-right-radius:4px;border-bottom:1px solid #d8d8d8}.bb-dialog-header .bb-dialog-header-content,.bb-dialog-header .bb-dialog-header-content h1{max-width:100%;font-size:20px;font-weight:500;overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.bb-dialog-header-row,.bb-dialog-header-navigation{width:100%;display:flex;align-items:center}.bb-dialog-header-row{padding:10px 20px}.bb-dialog-header-navigation{width:100%;padding:0 20px;overflow-x:auto;white-space:nowrap}.bb-dialog-header-navigation:empty{margin:0;height:0;padding:0;visibility:hidden}.bb-dialog-header-content{flex:1}.bb-dialog-header-close{width:32px;height:32px;border:none;min-width:32px;min-height:32px;overflow:hidden;margin-left:10px;border-radius:4px;position:relative;margin-right:-10px;display:inline-block;background-color:transparent}.bb-dialog-header-close:before,.bb-dialog-header-close:after{top:50%;left:20%;width:60%;height:2px;content:\"\";margin-top:-1px;position:absolute;background-color:#a2a9ba}.bb-dialog-header-close:before{transform:rotate(45deg)}.bb-dialog-header-close:after{transform:rotate(-45deg)}.bb-dialog-header-close:hover{background-color:#00000014}.bb-dialog-header-close:focus{background-color:#0000001f}.bb-dialog-header-close:active{background-color:#00000029}\n"], dependencies: [{ kind: "directive", type: i3.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbDialogHeader, decorators: [{
            type: Component,
            args: [{ selector: '[bb-dialog-header]', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, preserveWhitespaces: false, host: { 'class': 'bb-dialog-header' }, template: "<div class=\"bb-dialog-header-row\">\n    <div class=\"bb-dialog-header-content\">\n        <ng-content></ng-content>\n    </div>\n\n    <button *ngIf=\"closeRequested?.observed\"\n            (click)=\"closeRequested?.emit()\"\n            type=\"button\"\n            class=\"bb-dialog-header-close\">\n    </button>\n</div>\n\n<nav class=\"bb-dialog-header-navigation\">\n    <ng-content select=\"[bb-dialog-link]\"></ng-content>\n</nav>\n", styles: [".bb-dialog-header{display:flex;min-height:60px;flex-direction:column;justify-content:center;background-color:#fff;border-top-left-radius:4px;border-top-right-radius:4px;border-bottom:1px solid #d8d8d8}.bb-dialog-header .bb-dialog-header-content,.bb-dialog-header .bb-dialog-header-content h1{max-width:100%;font-size:20px;font-weight:500;overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.bb-dialog-header-row,.bb-dialog-header-navigation{width:100%;display:flex;align-items:center}.bb-dialog-header-row{padding:10px 20px}.bb-dialog-header-navigation{width:100%;padding:0 20px;overflow-x:auto;white-space:nowrap}.bb-dialog-header-navigation:empty{margin:0;height:0;padding:0;visibility:hidden}.bb-dialog-header-content{flex:1}.bb-dialog-header-close{width:32px;height:32px;border:none;min-width:32px;min-height:32px;overflow:hidden;margin-left:10px;border-radius:4px;position:relative;margin-right:-10px;display:inline-block;background-color:transparent}.bb-dialog-header-close:before,.bb-dialog-header-close:after{top:50%;left:20%;width:60%;height:2px;content:\"\";margin-top:-1px;position:absolute;background-color:#a2a9ba}.bb-dialog-header-close:before{transform:rotate(45deg)}.bb-dialog-header-close:after{transform:rotate(-45deg)}.bb-dialog-header-close:hover{background-color:#00000014}.bb-dialog-header-close:focus{background-color:#0000001f}.bb-dialog-header-close:active{background-color:#00000029}\n"] }]
        }], propDecorators: { closeRequested: [{
                type: Output
            }] } });

class BbDialogLink {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbDialogLink, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.0.6", type: BbDialogLink, selector: "[bb-dialog-link]", host: { classAttribute: "bb-dialog-link" }, ngImport: i0, template: "<ng-content></ng-content>\n", styles: [".bb-dialog-link{border:none;height:30px;display:flex;font-size:16px;appearance:none;font-weight:500;white-space:nowrap;align-items:center;color:#6b5c5c!important;background-color:transparent;text-decoration:none!important;border-bottom:2px solid transparent}.bb-dialog-link+.bb-dialog-link{margin-left:10px}.bb-dialog-link:hover:not(.disabled){border-bottom:2px solid rgba(117,119,148,.2)}.bb-dialog-link.active,.bb-dialog-link.active:hover{color:#5b53ff!important;border-bottom-color:#5b53ff}.bb-dialog-link.disabled,.bb-dialog-link.disabled:focus,.bb-dialog-link.disabled:hover,.bb-dialog-link.disabled:active{opacity:.4;cursor:default;box-shadow:none}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbDialogLink, decorators: [{
            type: Component,
            args: [{ selector: '[bb-dialog-link]', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, preserveWhitespaces: false, host: { 'class': 'bb-dialog-link' }, template: "<ng-content></ng-content>\n", styles: [".bb-dialog-link{border:none;height:30px;display:flex;font-size:16px;appearance:none;font-weight:500;white-space:nowrap;align-items:center;color:#6b5c5c!important;background-color:transparent;text-decoration:none!important;border-bottom:2px solid transparent}.bb-dialog-link+.bb-dialog-link{margin-left:10px}.bb-dialog-link:hover:not(.disabled){border-bottom:2px solid rgba(117,119,148,.2)}.bb-dialog-link.active,.bb-dialog-link.active:hover{color:#5b53ff!important;border-bottom-color:#5b53ff}.bb-dialog-link.disabled,.bb-dialog-link.disabled:focus,.bb-dialog-link.disabled:hover,.bb-dialog-link.disabled:active{opacity:.4;cursor:default;box-shadow:none}\n"] }]
        }] });

class BbDialogActions {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbDialogActions, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.0.6", type: BbDialogActions, selector: "[bb-dialog-actions]", host: { classAttribute: "bb-dialog-actions" }, ngImport: i0, template: "<bb-form-group class=\"end\">\n    <ng-content></ng-content>\n</bb-form-group>\n", styles: [".bb-dialog-actions{padding:20px;display:block;background-color:#fff;border-top:1px solid #d8d8d8;border-bottom-left-radius:4px;border-bottom-right-radius:4px}\n"], dependencies: [{ kind: "component", type: i1$1.BbFormGroup, selector: "bb-form-group", inputs: ["grouped"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbDialogActions, decorators: [{
            type: Component,
            args: [{ selector: '[bb-dialog-actions]', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, preserveWhitespaces: false, host: { 'class': 'bb-dialog-actions' }, template: "<bb-form-group class=\"end\">\n    <ng-content></ng-content>\n</bb-form-group>\n", styles: [".bb-dialog-actions{padding:20px;display:block;background-color:#fff;border-top:1px solid #d8d8d8;border-bottom-left-radius:4px;border-bottom-right-radius:4px}\n"] }]
        }] });

const bbDialogContainerAnimation = trigger('bbDialogContainerAnimation', [
    transition(':enter', [
        group([
            query('.bb-dialog-container-backdrop', [
                style({ opacity: 0 }),
                animate('180ms cubic-bezier(0, 0, 0.2, 1)', style({ opacity: 1 }))
            ]),
            query('.bb-dialog-container-component', [
                style({ opacity: 0, transform: 'scale(0.96)' }),
                animate('180ms cubic-bezier(0, 0, 0.2, 1)', style({ opacity: 1, transform: 'none' }))
            ])
        ])
    ]),
    transition(':leave', [
        group([
            query('.bb-dialog-container-backdrop', [
                animate('180ms cubic-bezier(0, 0, 0.2, 1)', style({ opacity: 0 }))
            ]),
            query('.bb-dialog-container-component', [
                animate('180ms cubic-bezier(0, 0, 0.2, 1)', style({
                    opacity: 0,
                    transform: 'scale(0.96)'
                }))
            ])
        ])
    ])
]);

class BbDialogInsertion {
    constructor(viewContainerRef) {
        this.viewContainerRef = viewContainerRef;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbDialogInsertion, deps: [{ token: i0.ViewContainerRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.0.6", type: BbDialogInsertion, selector: "[bbDialogInsertion]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbDialogInsertion, decorators: [{
            type: Directive,
            args: [{
                    selector: '[bbDialogInsertion]'
                }]
        }], ctorParameters: () => [{ type: i0.ViewContainerRef }] });

class BbDialogContainer {
    get onOverlayClicked() {
        return this.overlayClicked$.pipe(take(1));
    }
    constructor(_elementRef, _config) {
        this._elementRef = _elementRef;
        this._config = _config;
        // Readonly data.
        this.disableContainerAnimations = this._config?.disableContainerAnimations ?? false;
        // Data.
        this.componentRef = null;
        this.childComponentType = null;
        // State.
        this.overlayClicked$ = new Subject();
        // Subscription.
        this._subscription = new Subscription();
    }
    ngOnInit() {
        // Load the child component.
        this.loadChildComponent(this.childComponentType);
        // Listen for mouse click on the dialog container.
        this.listenForClicks();
    }
    ngOnDestroy() {
        this._subscription?.unsubscribe();
    }
    onAnimationDone(event) {
        // Check if the dialog is being destroyed.
        if (event?.toState !== 'void') {
            return;
        }
        // Destroy the ref if it exists.
        this.componentRef?.destroy();
    }
    listenForClicks() {
        const element = this._elementRef?.nativeElement ?? null;
        if (!element) {
            return;
        }
        const mouseDown$ = fromEvent(element, 'mousedown');
        const touchStart$ = fromEvent(element, 'touchstart');
        const start$ = race([mouseDown$, touchStart$]);
        const mouseUp$ = fromEvent(element, 'mouseup');
        const touchEnd$ = fromEvent(element, 'touchend');
        const end$ = race([mouseUp$, touchEnd$]);
        const clicks$ = start$.pipe(switchMap(() => end$));
        const subscription = clicks$.subscribe(() => this.overlayClicked$.next());
        this._subscription.add(subscription);
    }
    loadChildComponent(componentType) {
        // Get the view container ref and clear it.
        const viewContainerRef = this.insertion.viewContainerRef;
        viewContainerRef.clear();
        // Create an instance of the component.
        this.componentRef = viewContainerRef.createComponent(componentType);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbDialogContainer, deps: [{ token: i0.ElementRef }, { token: DialogConfig, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.0.6", type: BbDialogContainer, selector: "bb-dialog-container", host: { listeners: { "@bbDialogContainerAnimation.done": "onAnimationDone($event)" }, properties: { "@bbDialogContainerAnimation": "true", "@.disabled": "disableContainerAnimations" }, classAttribute: "bb-dialog-container" }, viewQueries: [{ propertyName: "insertion", first: true, predicate: BbDialogInsertion, descendants: true, static: true }], ngImport: i0, template: "<div class=\"bb-dialog-container-backdrop\"></div>\n\n<div class=\"bb-dialog-container-component\">\n    <ng-container bbDialogInsertion></ng-container>\n</div>\n", styles: [".bb-dialog-container,.bb-dialog-container-backdrop{inset:0;z-index:1000;position:fixed}.bb-dialog-container{display:flex}.bb-dialog-container-backdrop{will-change:opacity;background-color:#1119}.bb-dialog-container-component{width:100%;margin:auto;padding:20px;z-index:1001;display:block;will-change:opacity,transform}\n"], dependencies: [{ kind: "directive", type: BbDialogInsertion, selector: "[bbDialogInsertion]" }], animations: [bbDialogContainerAnimation], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbDialogContainer, decorators: [{
            type: Component,
            args: [{ selector: 'bb-dialog-container', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, host: {
                        'class': 'bb-dialog-container',
                        '[@bbDialogContainerAnimation]': 'true',
                        '[@.disabled]': 'disableContainerAnimations'
                    }, preserveWhitespaces: false, animations: [bbDialogContainerAnimation], template: "<div class=\"bb-dialog-container-backdrop\"></div>\n\n<div class=\"bb-dialog-container-component\">\n    <ng-container bbDialogInsertion></ng-container>\n</div>\n", styles: [".bb-dialog-container,.bb-dialog-container-backdrop{inset:0;z-index:1000;position:fixed}.bb-dialog-container{display:flex}.bb-dialog-container-backdrop{will-change:opacity;background-color:#1119}.bb-dialog-container-component{width:100%;margin:auto;padding:20px;z-index:1001;display:block;will-change:opacity,transform}\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: DialogConfig, decorators: [{
                    type: Optional
                }] }], propDecorators: { insertion: [{
                type: ViewChild,
                args: [BbDialogInsertion, { static: true }]
            }], onAnimationDone: [{
                type: HostListener,
                args: ['@bbDialogContainerAnimation.done', ['$event']]
            }] } });

let nextUniqueId = 0;
class BbDialogConfirm {
    constructor(_config, _dialogRef) {
        this._config = _config;
        this._dialogRef = _dialogRef;
        // Readonly data.
        this.title = this._config?.data?.title ?? null;
        this.description = this._config?.data?.description ?? null;
        this.confirmButtonText = this._config?.data?.confirmButtonText ?? 'dialog.default_confirm_button';
        this.cancelButtonText = this._config?.data?.cancelButtonText ?? 'dialog.default_cancel_button';
        this.confirmButtonClass = this._config?.data?.confirmButtonClass ?? null;
        this.cancelButtonClass = this._config?.data?.cancelButtonClass ?? null;
        this.width = this._config?.data?.width ?? '420px';
        // Id.
        this.dialogId = `bb-dialog-confirm-${nextUniqueId++}`;
    }
    ngAfterViewInit() {
        // Initial focus the button.
        this.confirmButton?.focus();
    }
    onClose(result) {
        this._dialogRef.close(result);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbDialogConfirm, deps: [{ token: BbDialogConfig }, { token: BbDialogRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.0.6", type: BbDialogConfirm, selector: "bb-dialog-confirm", host: { classAttribute: "bb-dialog-confirm" }, viewQueries: [{ propertyName: "confirmButton", first: true, predicate: ["confirm"], descendants: true, read: BbButton }], ngImport: i0, template: "<div [attr.aria-labelledby]=\"dialogId\"\n     [maxWidth]=\"width\"\n     bb-dialog-modal\n     bbFocusTrap>\n    <header bb-dialog-header>\n        <h1 *ngIf=\"title as titleContent\"\n            [id]=\"dialogId\">\n            <ng-template [bbTemplate]=\"titleContent\">\n                {{ $any(titleContent) | bbLocalize:{optional: true} }}\n            </ng-template>\n        </h1>\n    </header>\n\n    <p *ngIf=\"description as descriptionContent\"\n       class=\"bb-dialog-confirm-description\">\n        <ng-template [bbTemplate]=\"descriptionContent\">\n            {{ $any(descriptionContent) | bbLocalize:{optional: true} }}\n        </ng-template>\n    </p>\n\n    <footer bb-dialog-actions>\n        <button *ngIf=\"cancelButtonText as cancelButtonTextLabel\"\n                [ngClass]=\"cancelButtonClass ? cancelButtonClass : null\"\n                (click)=\"onClose(false)\"\n                bb-button\n                type=\"button\">\n            {{ cancelButtonTextLabel | bbLocalize:{optional: true} }}\n        </button>\n        <button #confirm\n                *ngIf=\"confirmButtonText as confirmButtonTextLabel\"\n                [ngClass]=\"confirmButtonClass ? confirmButtonClass : 'destructive'\"\n                (click)=\"onClose(true)\"\n                bb-button\n                type=\"button\">\n            {{ confirmButtonTextLabel | bbLocalize:{optional: true} }}\n        </button>\n    </footer>\n</div>\n", styles: [".bb-dialog-confirm{display:block}.bb-dialog-confirm-description{line-height:2}\n"], dependencies: [{ kind: "directive", type: i3.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i3.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i1$1.BbButton, selector: "button[bb-button]", inputs: ["disabled", "loading"], exportAs: ["bbButton"] }, { kind: "directive", type: i5.BbTemplate, selector: "[bbTemplate]", inputs: ["bbTemplate"] }, { kind: "directive", type: i5.BbFocusTrap, selector: "[bbFocusTrap]" }, { kind: "component", type: BbDialogModal, selector: "[bb-dialog-modal]", inputs: ["maxWidth"] }, { kind: "component", type: BbDialogHeader, selector: "[bb-dialog-header]", outputs: ["closeRequested"] }, { kind: "component", type: BbDialogActions, selector: "[bb-dialog-actions]" }, { kind: "pipe", type: i9.BbLocalize, name: "bbLocalize" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbDialogConfirm, decorators: [{
            type: Component,
            args: [{ selector: 'bb-dialog-confirm', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, preserveWhitespaces: false, host: { 'class': 'bb-dialog-confirm' }, template: "<div [attr.aria-labelledby]=\"dialogId\"\n     [maxWidth]=\"width\"\n     bb-dialog-modal\n     bbFocusTrap>\n    <header bb-dialog-header>\n        <h1 *ngIf=\"title as titleContent\"\n            [id]=\"dialogId\">\n            <ng-template [bbTemplate]=\"titleContent\">\n                {{ $any(titleContent) | bbLocalize:{optional: true} }}\n            </ng-template>\n        </h1>\n    </header>\n\n    <p *ngIf=\"description as descriptionContent\"\n       class=\"bb-dialog-confirm-description\">\n        <ng-template [bbTemplate]=\"descriptionContent\">\n            {{ $any(descriptionContent) | bbLocalize:{optional: true} }}\n        </ng-template>\n    </p>\n\n    <footer bb-dialog-actions>\n        <button *ngIf=\"cancelButtonText as cancelButtonTextLabel\"\n                [ngClass]=\"cancelButtonClass ? cancelButtonClass : null\"\n                (click)=\"onClose(false)\"\n                bb-button\n                type=\"button\">\n            {{ cancelButtonTextLabel | bbLocalize:{optional: true} }}\n        </button>\n        <button #confirm\n                *ngIf=\"confirmButtonText as confirmButtonTextLabel\"\n                [ngClass]=\"confirmButtonClass ? confirmButtonClass : 'destructive'\"\n                (click)=\"onClose(true)\"\n                bb-button\n                type=\"button\">\n            {{ confirmButtonTextLabel | bbLocalize:{optional: true} }}\n        </button>\n    </footer>\n</div>\n", styles: [".bb-dialog-confirm{display:block}.bb-dialog-confirm-description{line-height:2}\n"] }]
        }], ctorParameters: () => [{ type: BbDialogConfig }, { type: BbDialogRef }], propDecorators: { confirmButton: [{
                type: ViewChild,
                args: ['confirm', { read: BbButton, static: false }]
            }] } });

class Dialog {
    constructor(_injector, _applicationRef, _environmentInjector) {
        this._injector = _injector;
        this._applicationRef = _applicationRef;
        this._environmentInjector = _environmentInjector;
    }
    open(componentType, config) {
        return this.createDialog(componentType, config);
    }
    async confirm(title, description, options) {
        const dialogRef = this.open(BbDialogConfirm, {
            data: { title, description, ...(options ?? {}) }
        });
        return await firstValueFrom(dialogRef.afterClosed);
    }
    createDialog(componentType, config) {
        // Create a reference.
        const dialogRef = new BbDialogRef();
        const environmentInjector = createEnvironmentInjector([
            { provide: BbDialogConfig, useValue: config ?? {} },
            { provide: BbDialogRef, useValue: dialogRef }
        ], this._environmentInjector);
        const dialogComponentRef = createComponent(BbDialogContainer, { environmentInjector });
        // Attach the host view to the application.
        this._applicationRef.attachView(dialogComponentRef.hostView);
        try {
            // Remove the current focus.
            const activeElement = document.activeElement;
            activeElement.blur();
            // Append the element to the DOM.
            document.body.appendChild(dialogComponentRef.location.nativeElement);
        }
        catch {
            // Don't do anything, because it must've failed.
        }
        // Set the child component type on the component.
        dialogComponentRef.instance.childComponentType = componentType;
        dialogComponentRef.instance.onOverlayClicked.subscribe(() => dialogRef.onOverlayClicked());
        // Listen for close events.
        dialogRef.afterClosed.subscribe(() => this.deleteDialog(dialogComponentRef));
        // Return the reference.
        return dialogRef;
    }
    deleteDialog(dialogComponentRef) {
        // Only continue if the dialog component ref exists.
        if (!dialogComponentRef) {
            return;
        }
        // Detach the dialog.
        this._applicationRef.detachView(dialogComponentRef.hostView);
        // Destroy the dialog.
        dialogComponentRef.destroy();
        dialogComponentRef = null;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: Dialog, deps: [{ token: i0.Injector }, { token: i0.ApplicationRef }, { token: i0.EnvironmentInjector }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: Dialog }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: Dialog, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i0.Injector }, { type: i0.ApplicationRef }, { type: i0.EnvironmentInjector }] });

class DialogModule {
    static forRoot(config) {
        return {
            ngModule: DialogModule,
            providers: [
                Dialog,
                { provide: DialogConfig, useValue: config },
            ]
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: DialogModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.0.6", ngImport: i0, type: DialogModule, declarations: [BbDialogContainer,
            BbDialogOverlay,
            BbDialogModal,
            BbDialogHeader,
            BbDialogLink,
            BbDialogActions,
            BbDialogConfirm,
            BbDialogInsertion], imports: [CommonModule,
            LocalizeModule,
            ElementsModule], exports: [BbDialogOverlay,
            BbDialogModal,
            BbDialogHeader,
            BbDialogLink,
            BbDialogActions] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: DialogModule, imports: [CommonModule,
            LocalizeModule,
            ElementsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: DialogModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        LocalizeModule,
                        ElementsModule
                    ],
                    declarations: [
                        BbDialogContainer,
                        BbDialogOverlay,
                        BbDialogModal,
                        BbDialogHeader,
                        BbDialogLink,
                        BbDialogActions,
                        BbDialogConfirm,
                        BbDialogInsertion
                    ],
                    exports: [
                        BbDialogOverlay,
                        BbDialogModal,
                        BbDialogHeader,
                        BbDialogLink,
                        BbDialogActions
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BbDialogActions, BbDialogConfig, BbDialogHeader, BbDialogLink, BbDialogModal, BbDialogOverlay, BbDialogRef, Dialog, DialogConfig, DialogModule };
//# sourceMappingURL=bravobit-bb-foundation-dialog.mjs.map
