import * as i0 from '@angular/core';
import { InjectionToken, Optional, Inject, Directive, Input, Component, ChangeDetectionStrategy, ViewEncapsulation, ContentChildren, Injectable, inject, LOCALE_ID, Pipe, APP_INITIALIZER, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { formatDate, DOCUMENT, CommonModule } from '@angular/common';
import { __param, __decorate } from 'tslib';
import { startWith, map, distinctUntilChanged } from 'rxjs/operators';
import { Subscription, BehaviorSubject, of } from 'rxjs';
import * as i2 from '@bravobit/bb-foundation/utils';
import { UtilsModule } from '@bravobit/bb-foundation/utils';
import * as i2$1 from '@bravobit/bb-foundation';
import { WINDOW } from '@bravobit/bb-foundation';
import * as i1$1 from '@bravobit/bb-foundation/storage';

//
// The configuration that can be passed when
// the user initializes the localize module.
//
class LocalizeConfig {
}

//
// These are the options that the user has
// when localizing the token.
//

//
// This is the injection token that will be injected
// into the service so that the all localize functions
// can retrieved and used.
//
const LOCALIZE_FUNCTION = new InjectionToken('localize_function');

const LOCALIZE_TRANSFORM = new InjectionToken('localize_transform');

//
// This function transform the value
// to a lowercase variant of the value.
//
class LocalizeLowercaseFunction {
    keyword() {
        return 'lowercase';
    }
    transform(value) {
        return (value ?? '').toLowerCase();
    }
}

//
// This function transform the value
// to a uppercase variant of the value.
//
class LocalizeUppercaseFunction {
    keyword() {
        return 'uppercase';
    }
    transform(value) {
        return (value ?? '').toUpperCase();
    }
}

//
// This function transform the value
// to a localized date.
//
class LocalizeDateFunction {
    keyword() {
        return 'date';
    }
    transform(value, locale) {
        const date = new Date(value);
        if (date.toString() === 'Invalid Date') {
            return '?';
        }
        return formatDate(date, 'longDate', locale);
    }
}

const extraEnglishDictionary = {
    'form-control-errors': {
        'unknown': 'The field has an unknown error.',
        'required': 'This field is required.',
        'pattern': 'Invalid format.',
        'email': 'The field does not match a valid email address.',
        'emailTaken': 'The e-mail is already taken.',
        'passwordMatch': 'The passwords don\'t match.',
        'confirm': 'The field does not match.',
        'fullNumber': 'The field should be a full number.',
        'min': 'Minimum amount should be {{min}}.',
        'max': 'Maximum amount should be {{max}}.',
        'invalidFileType': 'The file type is not allowed.',
        'maxFileSize': 'The file has exceed the maximum amount of {{maxSize}}.',
        'minDate': 'The first accepted date is {{date|date}}.',
        'maxDate': 'The last accepted date is {{date|date}}.',
        'invalidDate': 'The field contains an invalid date.',
        'minlength': 'Expected a minimum of {{requiredLength}} characters but got {{actualLength}} characters.',
        'maxlength': 'Expected a maximum of {{requiredLength}} characters but got {{actualLength}} characters.'
    },
    'tables': {
        'search': 'Search...',
        'loading': 'Loading...',
        'empty': 'There is nothing to find here.',
        'page': 'page',
        'error_datasource': 'No data source was provided.',
        'error_unauthorized': 'You need to be authenticated to view this data.',
        'error_forbidden': 'You do not have access to view this data.',
        'error_not_found': 'The data was not found.',
        'error_server': 'A server error occurred while fetching data from the server.',
        'error_down': 'It looks like the server is down.',
        'error_unknown': 'A unknown error occurred.'
    },
    'file-picker': {
        'choose': 'Choose file',
        'remove': 'Remove file',
        'drop': 'or drag and drop file here'
    },
    'times': {
        'tomorrow_at': 'Tomorrow at {{date}}',
        'today_at': 'Today at {{date}}',
        'yesterday_at': 'Yesterday at {{date}}'
    }
};

const extraDutchDictionary = {
    'form-control-errors': {
        'unknown': 'Het veld heeft een onbekende fout.',
        'required': 'Dit veld is verplicht.',
        'pattern': 'Ongeldig formaat.',
        'email': 'Het veld komt niet overeen met een geldig e-mailadres.',
        'emailTaken': 'Het e-mailadres is al bezet.',
        'passwordMatch': 'De wachtwoorden komen niet overeen.',
        'confirm': 'Het veld komt niet overeen.',
        'fullNumber': 'Het veld moet een volledig getal zijn.',
        'min': 'Minimum hoeveelheid moet {{min}} zijn.',
        'max': 'Maximum hoeveelheid moet {{max}} zijn.',
        'invalidFileType': 'Het type bestand is niet toegestaan.',
        'maxFileSize': 'Het bestand heeft de maximum hoeveelheid van {{maxSize}} overschreden.',
        'minDate': 'De eerst mogelijke datum is {{date|date}}.',
        'maxDate': 'De laatst mogelijke datum is {{date|date}}.',
        'invalidDate': 'Het veld bevat een ongeldige datum.',
        'minlength': 'Verwachtte minimaal {{requiredLength}} tekens, maar kreeg {{actualLength}} tekens.',
        'maxlength': 'Verwachtte maximaal {{requiredLength}} tekens, maar kreeg {{actualLength}} tekens.'
    },
    'tables': {
        'search': 'Zoeken...',
        'loading': 'Aan het laden...',
        'empty': 'Er is hier niets te vinden.',
        'page': 'pagina',
        'error_datasource': 'Er is geen gegevensbron verstrekt.',
        'error_unauthorized': 'U moet ingelogd zijn om deze gegevens te bekijken.',
        'error_forbidden': 'U hebt geen toegang om deze gegevens te bekijken.',
        'error_not_found': 'De gegevens zijn niet gevonden.',
        'error_server': 'Er is een serverfout opgetreden bij het ophalen van gegevens van de server.',
        'error_down': 'Het lijkt erop dat de server down is.',
        'error_unknown': 'Er is een onbekende fout opgetreden bij het ophalen van gegevens van de server.'
    },
    'file-picker': {
        'choose': 'Kies bestand',
        'remove': 'Verwijder bestand',
        'drop': 'of sleep het bestand hiernaartoe'
    },
    'times': {
        'tomorrow_at': 'Morgen om {{date}}',
        'today_at': 'Vandaag om {{date}}',
        'yesterday_at': 'Gisteren om {{date}}'
    }
};

class LocalizeMissingHandler {
    constructor() {
        this.log = (message) => console?.warn?.(message);
    }
    handle(params) {
        // Log to the console when the token was not found
        // if the user did not mark it as optional.
        if (!params?.optional) {
            this.log(`The token with name: "${params?.token}" was not found.`);
        }
        // Return the default token back.
        return params?.token ?? null;
    }
}

class LocalizeDictionaryData {
    constructor(data) {
        this.data = data;
    }
}

class LocalizeDictionaryContext {
    constructor() {
        this.regexp = /^.*$/;
    }
    pattern(regexp) {
        this.regexp = regexp;
        return this;
    }
    matches(value) {
        const formatted = this.formatValue(value);
        const regex = (formatted ?? '')
            .replace(/[-[\]{}()*+?.,\\^$|#\s]/g, '\\$&')
            .replace(/\\\*/g, '.*');
        return this.pattern(new RegExp(`^${regex}$`));
    }
    group(value) {
        const formatted = this.formatValue(value);
        return this.matches([formatted, '*']);
    }
    formatValue(value) {
        return Array.isArray(value)
            ? value.filter(item => !!item).join('.')
            : value;
    }
}

class LocalizeDictionary {
    constructor(_id, _locale, _supported, _dataValues, _localize) {
        this._id = _id;
        this._locale = _locale;
        this._supported = _supported;
        this._dataValues = _dataValues;
        this._localize = _localize;
        this._data = this.formatData(this._dataValues);
    }
    get id() {
        return this._id ?? null;
    }
    get locale() {
        return this._locale ?? null;
    }
    get supported() {
        return this._supported ?? [];
    }
    get(token) {
        const key = Array.isArray(token) ? token.join('.') : token;
        return this._data?.[key] ?? null;
    }
    has(token) {
        return !!this.get(token);
    }
    all() {
        return this.some(context => context);
    }
    some(callback) {
        const defaultContext = new LocalizeDictionaryContext();
        const context = !!callback ? callback(defaultContext) : defaultContext;
        return Object.keys(this._data ?? {})
            .filter(key => context.regexp.test(key))
            .reduce((previous, current) => ([
            ...previous,
            { token: current, value: this.get(current) }
        ]), []);
    }
    async compare(to) {
        if ((typeof ngDevMode === 'undefined' || ngDevMode)) {
            const dictionaryIds = (Array.isArray(to) ? to : [to]);
            const dictionaries = [];
            for (const dictionaryId of dictionaryIds) {
                const dictionary = await this._localize.load(dictionaryId);
                dictionaries.push(dictionary);
            }
            const warnings = [];
            const items = this.all();
            for (const item of items) {
                for (const dictionary of dictionaries) {
                    if (!dictionary.has(item?.token)) {
                        warnings.push({ dictionary: dictionary?.id, value: item?.token });
                    }
                }
            }
            for (const dictionary of dictionaries) {
                const items = dictionary.all();
                for (const item of items) {
                    if (!this.has(item?.token)) {
                        warnings.push({ dictionary: this.id, value: item?.token });
                    }
                }
            }
            const compareDictionaryIds = dictionaries.map(dictionary => dictionary?.id).join(', ');
            for (const warning of warnings) {
                console?.warn?.(`Dictionary "${warning.dictionary}" is missing token "${warning.value}"`);
            }
            console?.warn?.(`Total of ${warnings.length} warning(s) found while comparing "${this.id}" -> [${compareDictionaryIds}].`);
        }
    }
    count() {
        return Object.keys(this._data ?? {}).length;
    }
    formatData(data, scope = null) {
        return Object.keys(data ?? {}).reduce((previous, current) => {
            const value = data?.[current];
            if (typeof value === 'object' && value !== null) {
                const reformatted = this.formatData(value, current);
                return { ...previous, ...reformatted };
            }
            const token = [scope, current].filter(item => !!item).join('.');
            if (previous[token] && (typeof ngDevMode === 'undefined' || ngDevMode)) {
                console?.warn?.(`Duplicate key "${token}" was found, please verify your translation files.`);
            }
            return { ...previous, [token]: value };
        }, {});
    }
}

class LocalizeTransform {
    getMatches(value, substitutions) {
        // Validate our value exists, else return zero matches.
        if (value === undefined || value === null) {
            return [];
        }
        // Get the matching substitutions.
        const { start, end } = this.getSubstitutions(substitutions);
        // Compose a regex that will find the matches.
        const regex = new RegExp(`${start}([^${end}]+)${end}`, 'g');
        // Execute the regex to find matches.
        let match = regex.exec(value);
        const matches = [];
        while (match !== null) {
            matches.push({ match: match[0], token: match[1] });
            match = regex.exec(value);
        }
        // Return the processed value.
        return matches.filter(item => !!item);
    }
    getSubstitutions(value) {
        // Escape both substitutions so that they can be used.
        const escape = /[.*+?^${}()|[\]\\]/g;
        const start = value[0].replace(escape, '\\$&');
        const end = value[1].replace(escape, '\\$&');
        // Return the substitutions.
        return { start, end };
    }
}

let LocalizePluralTransform = class LocalizePluralTransform extends LocalizeTransform {
    constructor(config) {
        super();
        this.config = config;
        this.substitutions = this.config?.substitutions?.plural ?? ['@plural(', ')'];
        this.defaultAmount = 'default';
        this.multiItemRegex = new RegExp(`(?<value>=([0-9]+|${this.defaultAmount}): *[^,]+)`, 'g');
        this.singleItemRegex = new RegExp(`(=(?<amount>[0-9]+|${this.defaultAmount}): *(?<sentence>.+))`);
    }
    execute(value, data, _) {
        const matches = this.getMatches(value, this.substitutions);
        return matches.reduce((previous, current) => {
            const [variable, content] = current.token?.split('|');
            const amount = this.extractAmount(variable, data);
            const pluralToken = this.parsePluralToken(content, amount);
            return previous.replace(current?.match, pluralToken ?? current?.match);
        }, value);
    }
    extractAmount(variable, data) {
        const trimmedVariable = variable?.trim();
        const value = data?.[trimmedVariable] ?? null;
        return typeof value === 'string' || typeof value === 'number'
            ? value
            : null;
    }
    parsePluralToken(value, amount) {
        const plural = this.getPluralObject(value);
        return plural?.[amount] ?? plural?.[this.defaultAmount] ?? null;
    }
    splitMatches(value) {
        let match = this.multiItemRegex.exec(value);
        const matches = [];
        while (match !== null) {
            matches.push(match[0]);
            match = this.multiItemRegex.exec(value);
        }
        return matches;
    }
    getPluralObject(value) {
        const matches = this.splitMatches(value);
        return matches.reduce((previous, current) => {
            const result = current.match(this.singleItemRegex);
            const amount = result.groups['amount'].trim();
            const sentence = result.groups['sentence'].trim();
            return { ...previous, [amount]: sentence };
        }, {});
    }
};
LocalizePluralTransform = __decorate([
    __param(0, Optional())
], LocalizePluralTransform);

let LocalizeInterpolateTransform = class LocalizeInterpolateTransform extends LocalizeTransform {
    constructor(config, functions) {
        super();
        this.config = config;
        this.functions = functions;
        this.substitutions = this.config?.substitutions?.references ?? ['{{', '}}'];
        this.functionsMap = (this.functions ?? []).reduce((previous, current) => {
            previous[current?.keyword()] = current;
            return previous;
        }, {});
    }
    execute(value, data, localize) {
        const matches = this.getMatches(value, this.substitutions);
        // Replace all matches with the translated value.
        return matches.reduce((previous, current) => {
            // Try to parse the token.
            const interpolatedToken = this.parseInterpolationToken(current?.token, data, localize);
            // Replace the match with the translated token.
            return previous.replace(current?.match, interpolatedToken);
        }, value);
    }
    parseInterpolationToken(value, data, localize) {
        // Get the token and the methods by splitting
        // on the pipe symbol.
        const [token, ...methods] = (value ?? '').split('|').map(item => item.trim());
        // Get the value for the token from
        // the interpolation data.
        const interpolationValue = data?.[token] ?? 'null';
        // Loop through all the middleware methods and try to
        // conform the string to the given parameters.
        return methods.reduce((string, middlewareName) => {
            // Try to retrieve the middleware from the collection.
            const middleware = this.functionsMap?.[middlewareName];
            // If the middleware is missing return an error
            // so that the user knows it was not found.
            if (!middleware) {
                return string;
            }
            // Execute the middleware function with the string.
            return middleware.transform(string, localize?.current?.locale);
        }, `${interpolationValue}`);
    }
};
LocalizeInterpolateTransform = __decorate([
    __param(0, Optional()),
    __param(1, Optional()),
    __param(1, Inject(LOCALIZE_FUNCTION))
], LocalizeInterpolateTransform);

let LocalizeReferenceTransform = class LocalizeReferenceTransform extends LocalizeTransform {
    constructor(config) {
        super();
        this.config = config;
        this.substitutions = this.config?.substitutions?.references ?? ['#(', ')'];
    }
    execute(value, _, localize) {
        const matches = this.getMatches(value, this.substitutions);
        // Replace all matches with the translated value.
        return matches.reduce((previous, current) => {
            // Try to translate the token.
            const translatedToken = localize.translate(current?.token);
            // Replace the match with the translated token.
            return previous.replace(current?.match, translatedToken);
        }, value);
    }
};
LocalizeReferenceTransform = __decorate([
    __param(0, Optional())
], LocalizeReferenceTransform);

class BbLocalizeTemplate {
    constructor(templateRef) {
        this.templateRef = templateRef;
        // Inputs.
        this.name = null;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbLocalizeTemplate, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.0.6", type: BbLocalizeTemplate, selector: "[bbLocalizeTemplate]", inputs: { name: ["bbLocalizeTemplate", "name"] }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbLocalizeTemplate, decorators: [{
            type: Directive,
            args: [{
                    selector: '[bbLocalizeTemplate]'
                }]
        }], ctorParameters: () => [{ type: i0.TemplateRef }], propDecorators: { name: [{
                type: Input,
                args: ['bbLocalizeTemplate']
            }] } });

class BbLocalizeString {
    set value(value) {
        this._value = value;
        this.revalidate();
    }
    get value() {
        return this._value;
    }
    constructor(_changeDetection) {
        this._changeDetection = _changeDetection;
        // Inputs.
        this.substitutions = ['@element(', ')'];
        // Data.
        this.components = [];
        // Subscriptions.
        this._subscription = new Subscription();
        // State.
        this._value = null;
    }
    ngAfterViewInit() {
        this.observeItemChanges();
    }
    ngOnDestroy() {
        this._subscription?.unsubscribe();
    }
    observeItemChanges() {
        const subscription = this.items.changes.pipe(startWith(0)).subscribe(() => this.revalidate());
        this._subscription.add(subscription);
    }
    revalidate() {
        const items = this.items?.toArray() ?? [];
        if (items.length <= 0) {
            return;
        }
        this.setComponents(items);
    }
    setComponents(items) {
        const [start, end] = this.substitutions;
        const templates = items.reduce((previous, current) => {
            const template = current?.templateRef ?? null;
            const name = current?.name ?? null;
            if (!template || !name) {
                return previous;
            }
            return { ...previous, [`${start}${name}${end}`]: template };
        }, {});
        this.components = this.getStringComponents(this._value)
            .map(component => templates?.[component] ?? component ?? null)
            .filter(item => !!item);
        this._changeDetection.detectChanges();
    }
    getStringComponents(value) {
        const [start, end] = this.getSubstitutions();
        const regex = new RegExp(`(${start}[a-zA-Z]+${end})`, 'g');
        return value.split(regex);
    }
    getSubstitutions() {
        const [start, end] = this.substitutions;
        const escape = /[.*+?^${}()|[\]\\]/g;
        return [
            start.replace(escape, '\\$&'),
            end.replace(escape, '\\$&')
        ];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbLocalizeString, deps: [{ token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.0.6", type: BbLocalizeString, selector: "[bb-localize-string]", inputs: { substitutions: "substitutions", value: ["bb-localize-string", "value"] }, host: { attributes: { "ngSkipHydration": "true" }, classAttribute: "bb-localize-string" }, queries: [{ propertyName: "items", predicate: BbLocalizeTemplate }], ngImport: i0, template: "<ng-container *ngFor=\"let component of components\">\n    <ng-template [bbTemplate]=\"component\">{{ component }}</ng-template>\n</ng-container>\n", styles: [".bb-localize-string{display:inline}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.BbTemplate, selector: "[bbTemplate]", inputs: ["bbTemplate"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbLocalizeString, decorators: [{
            type: Component,
            args: [{ selector: '[bb-localize-string]', changeDetection: ChangeDetectionStrategy.OnPush, host: {
                        'class': 'bb-localize-string',
                        'ngSkipHydration': 'true'
                    }, encapsulation: ViewEncapsulation.None, preserveWhitespaces: false, template: "<ng-container *ngFor=\"let component of components\">\n    <ng-template [bbTemplate]=\"component\">{{ component }}</ng-template>\n</ng-container>\n", styles: [".bb-localize-string{display:inline}\n"] }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }], propDecorators: { items: [{
                type: ContentChildren,
                args: [BbLocalizeTemplate]
            }], substitutions: [{
                type: Input
            }], value: [{
                type: Input,
                args: ['bb-localize-string']
            }] } });

class Localize {
    constructor(_storage, _languages, _missingHandler, _config, _window, _document, _transforms) {
        this._storage = _storage;
        this._languages = _languages;
        this._missingHandler = _missingHandler;
        this._config = _config;
        this._window = _window;
        this._document = _document;
        this._transforms = _transforms;
        // Readonly data.
        this._storageToken = this._config?.storageToken ?? 'bb-language-dictionary-id';
        this._availableLanguages = this?._config?.languages ?? [];
        this._bestMatchingLanguage = this.retrieveBestMatchingLanguage();
        this._loadedDictionaries = new Map();
        // Current dictionary.
        this._current$ = new BehaviorSubject(null);
        // State changes.
        this.dictionaryChanges$ = this._current$.asObservable();
        this.convertToParams = (tokenOrParams) => {
            if (typeof tokenOrParams !== 'string') {
                // Destruct the params from the object.
                const { token, optional, dictionary, data } = tokenOrParams;
                // Make sure all parameters are valid
                // by type safe adding them.
                return { token: token, optional: optional ?? false, dictionary: dictionary ?? null, data: data ?? {} };
            }
            // If the parameter is a string fill in the blanks.
            return { token: tokenOrParams, optional: false, dictionary: null, data: {} };
        };
        this.renderDocumentLanguage();
    }
    get languages() {
        return this._availableLanguages ?? [];
    }
    get current() {
        return this._current$.getValue();
    }
    async load(id) {
        if (id === null || id === undefined) {
            throw new Error(`Cannot load language with id: "${id}".`);
        }
        if (this._loadedDictionaries.has(id)) {
            return this._loadedDictionaries.get(id);
        }
        const language = this.languages?.find(language => language?.id === id);
        if (!language || !language?.data) {
            console?.warn?.(`No language was found with id: "${id}"; Defaulting to first available language.`);
            const languageId = this.languages?.[0]?.id ?? null;
            return this.load(languageId);
        }
        const dictionaryDataValues = await language?.data?.();
        const dictionary = this.createDictionary(dictionaryDataValues, language);
        this._loadedDictionaries.set(id, dictionary);
        return dictionary;
    }
    async loadAllLanguages() {
        for (const language of this.languages) {
            await this.load(language?.id);
        }
    }
    async switch(id, options) {
        const dictionary = await this.load(id);
        this._current$.next(dictionary);
        const cache = options?.cache ?? true;
        if (cache) {
            this._storage.cookie.set(this._storageToken, dictionary?.id, {});
        }
        const reload = options?.reload ?? false;
        if (reload) {
            this._window?.location?.reload?.();
        }
        return dictionary;
    }
    select(id) {
        if (!this._loadedDictionaries.has(id)) {
            throw new Error(`Dictionary with id: "${id}" not loaded; Load dictionary first before using .select(:id).`);
        }
        return this._loadedDictionaries.get(id);
    }
    initialize() {
        return async () => {
            await this.switch(this._bestMatchingLanguage?.id, { reload: false, cache: false });
            return this.compareDictionaries();
        };
    }
    clear() {
        this._storage.cookie.remove(this._storageToken);
    }
    transform(value, data = {}) {
        return (this._transforms ?? []).reduce((previous, current) => {
            return current.execute(previous, data, this);
        }, value);
    }
    translate(tokenOrParams) {
        // 1. Convert to the params.
        const params = this.convertToParams(tokenOrParams);
        // 2. Try to find the translation in the dictionary.
        const dictionary = this.getDictionary(params?.dictionary);
        const searchResult = !!dictionary ? dictionary.get(params?.token) : null;
        // 3. Verify the translation was found.
        if (!searchResult) {
            return this._missingHandler.handle(params);
        }
        return this.transform(searchResult, params?.data);
    }
    retrieveBestMatchingLanguage() {
        return this.getLanguageFromStorage()
            ?? this.getBestBrowserMatchLanguage()
            ?? this._availableLanguages?.[0];
    }
    getLanguageFromStorage() {
        // Get id from the storage.
        const id = this._storage.cookie.get(this._storageToken);
        // Return the language based on the storage id.
        return this._availableLanguages.find(item => item?.id === id);
    }
    getBestBrowserMatchLanguage() {
        // Loop through all browser languages and return the
        // best matching language.
        return this._languages.all.map(({ code, region }) => {
            const languageCode = [code, region].filter(data => !!data).join('-');
            return this._availableLanguages.find(item => item?.supported?.includes(languageCode));
        }).filter(item => !!item).find((_, index) => index === 0);
    }
    createDictionary(data, language) {
        return new LocalizeDictionary(language?.id, language?.locale, language?.supported, data?.data, this);
    }
    getDictionary(id) {
        if (id === null || id === undefined) {
            return this.current;
        }
        return this.select(id);
    }
    renderDocumentLanguage() {
        const element = this._document?.documentElement;
        if (!element) {
            return;
        }
        element.lang = this._bestMatchingLanguage?.supported?.[0] ?? this._bestMatchingLanguage?.locale;
    }
    async compareDictionaries() {
        const compareDictionaries = this._config.compareDictionaries ?? false;
        if (!compareDictionaries || !this.current) {
            return;
        }
        const languageIds = (this.languages ?? [])
            ?.filter(language => language?.id !== this.current?.id)
            ?.map(language => language?.id);
        return await this.current.compare(languageIds);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: Localize, deps: [{ token: i1$1.Storage }, { token: i2$1.Languages }, { token: LocalizeMissingHandler }, { token: LocalizeConfig, optional: true }, { token: WINDOW, optional: true }, { token: DOCUMENT, optional: true }, { token: LOCALIZE_TRANSFORM, optional: true }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: Localize }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: Localize, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1$1.Storage }, { type: i2$1.Languages }, { type: LocalizeMissingHandler }, { type: LocalizeConfig, decorators: [{
                    type: Optional
                }] }, { type: Window, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [WINDOW]
                }] }, { type: Document, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [LOCALIZE_TRANSFORM]
                }] }] });

const LOCALIZE_ID = new InjectionToken('An abstraction over locale changes', {
    factory: () => {
        const localize = inject(Localize, { optional: true });
        if (!localize) {
            return of(inject(LOCALE_ID));
        }
        return localize.dictionaryChanges$.pipe(map(dictionary => dictionary?.locale ?? null), distinctUntilChanged(), startWith(localize?.current?.locale ?? null));
    }
});

class BbLocalize {
    constructor(_localize) {
        this._localize = _localize;
    }
    transform(tokenOrParams, args) {
        // Combine the params with the options to form the localize params.
        const params = this.combineParamsWithOptions(tokenOrParams, args);
        // Validate that the localize service exists in the pipe.
        if (!this._localize) {
            return params?.token ?? null;
        }
        // Try to localize the value.
        return this._localize.translate(params);
    }
    combineParamsWithOptions(tokenOrParams, args) {
        // Gather the extras.
        const extras = args ?? {};
        // Loop through all the keys to find the set options.
        const options = Object.keys(extras).reduce((previous, current) => {
            if (typeof extras?.[current] === 'undefined') {
                return previous;
            }
            return { ...previous, [current]: extras?.[current] };
        }, {});
        // Convert the string token to a params object.
        const params = typeof tokenOrParams === 'string'
            ? { token: tokenOrParams, optional: false, data: {}, dictionary: null }
            : tokenOrParams;
        // Return the combined params and options.
        return { ...params, ...options };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbLocalize, deps: [{ token: Localize, optional: true }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.6", ngImport: i0, type: BbLocalize, name: "bbLocalize" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbLocalize, decorators: [{
            type: Pipe,
            args: [{
                    name: 'bbLocalize'
                }]
        }], ctorParameters: () => [{ type: Localize, decorators: [{
                    type: Optional
                }] }] });

class LocalizeModule {
    static forRoot(config) {
        if (config?.languages?.length <= 0) {
            throw new Error('One or more languages should be supplied.');
        }
        if (config?.compareDictionaries && config?.mode === 'manual') {
            console?.warn?.('You cannot enable "compareDictionaries" when having mode set to "manual"; This setting will be ignored.');
        }
        const mode = config?.mode ?? 'automatic';
        return {
            ngModule: LocalizeModule,
            providers: [
                // Angular providers.
                ...(mode === 'automatic' ? [
                    { provide: APP_INITIALIZER, deps: [Localize], useFactory: initializeLocale, multi: true },
                    { provide: LOCALE_ID, deps: [Localize], useFactory: getLocale }
                ] : []),
                // Config provider.
                { provide: LocalizeConfig, useValue: config },
                // Function providers.
                { provide: LOCALIZE_FUNCTION, useClass: LocalizeLowercaseFunction, multi: true },
                { provide: LOCALIZE_FUNCTION, useClass: LocalizeUppercaseFunction, multi: true },
                { provide: LOCALIZE_FUNCTION, useClass: LocalizeDateFunction, multi: true },
                // Transform providers.
                { provide: LOCALIZE_TRANSFORM, useClass: LocalizePluralTransform, deps: [LocalizeConfig], multi: true },
                { provide: LOCALIZE_TRANSFORM, useClass: LocalizeReferenceTransform, deps: [LocalizeConfig], multi: true },
                { provide: LOCALIZE_TRANSFORM, useClass: LocalizeInterpolateTransform, deps: [LocalizeConfig, LOCALIZE_FUNCTION], multi: true },
                // Handler providers.
                { provide: LocalizeMissingHandler, useClass: LocalizeMissingHandler },
                // Service providers.
                Localize
            ]
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: LocalizeModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.0.6", ngImport: i0, type: LocalizeModule, declarations: [BbLocalize,
            BbLocalizeString,
            BbLocalizeTemplate], imports: [CommonModule, UtilsModule], exports: [BbLocalize,
            BbLocalizeString,
            BbLocalizeTemplate] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: LocalizeModule, imports: [CommonModule, UtilsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: LocalizeModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, UtilsModule],
                    declarations: [
                        BbLocalize,
                        BbLocalizeString,
                        BbLocalizeTemplate
                    ],
                    exports: [
                        BbLocalize,
                        BbLocalizeString,
                        BbLocalizeTemplate
                    ]
                }]
        }] });
function initializeLocale(localize) {
    return localize.initialize();
}
function getLocale(localize) {
    return localize?.current?.locale ?? null;
}

/**
 * Generated bundle index. Do not edit.
 */

export { BbLocalize, BbLocalizeString, BbLocalizeTemplate, LOCALIZE_FUNCTION, LOCALIZE_ID, LOCALIZE_TRANSFORM, Localize, LocalizeConfig, LocalizeDateFunction, LocalizeDictionary, LocalizeDictionaryContext, LocalizeDictionaryData, LocalizeInterpolateTransform, LocalizeLowercaseFunction, LocalizeMissingHandler, LocalizeModule, LocalizePluralTransform, LocalizeReferenceTransform, LocalizeTransform, LocalizeUppercaseFunction, extraDutchDictionary, extraEnglishDictionary, getLocale, initializeLocale };
//# sourceMappingURL=bravobit-bb-foundation-localize.mjs.map
