import * as i0 from '@angular/core';
import { InjectionToken, LOCALE_ID, Injectable, Optional, Inject, EventEmitter, forwardRef, Component, ChangeDetectionStrategy, ViewEncapsulation, HostBinding, Input, Output, NgModule } from '@angular/core';
import { DOCUMENT } from '@angular/common';
import * as i3 from 'rxjs';
import { BehaviorSubject, Subscription } from 'rxjs';
import * as i1 from '@angular/cdk/platform';
import * as i2 from '@bravobit/bb-foundation/localize';
import { LOCALIZE_ID } from '@bravobit/bb-foundation/localize';
import { mixinGrouped } from '@bravobit/bb-foundation';
import { NG_VALUE_ACCESSOR } from '@angular/forms';

const RECAPTCHA_CONFIG = new InjectionToken('bb-recaptcha-config');

class RecaptchaLoader {
    constructor(_platform, _renderFactory, _localize, _localeId, _document, _config) {
        this._platform = _platform;
        this._renderFactory = _renderFactory;
        this._localize = _localize;
        this._localeId = _localeId;
        this._document = _document;
        this._config = _config;
        // Ready state.
        this.ready$ = null;
        // Data.
        this._windowLoadFn = 'bbRecaptchaLoad';
        this._renderer = null;
        // Create a renderer.
        this._renderer = this._renderFactory.createRenderer(null, null);
        // Set the ready subject if not exists.
        if (this.ready$) {
            return;
        }
        this.ready$ = new BehaviorSubject(null);
        // Create the script.
        this.createScript(captcha => this.ready$.next(captcha));
    }
    createScript(callback) {
        // Validate we are on a browser.
        if (!this._platform.isBrowser) {
            return;
        }
        // Create the script.
        const script = this._renderer.createElement('script');
        // Set properties on the script.
        this._renderer.setProperty(script, 'src', this.getUrl());
        this._renderer.setProperty(script, 'async', true);
        this._renderer.setProperty(script, 'defer', true);
        // Set the nonce.
        if (this._config.nonce) {
            this._renderer.setAttribute(script, 'nonce', this._config.nonce);
        }
        // Set the loading function.
        if (this._platform.isBrowser) {
            window[this._windowLoadFn] = () => callback(grecaptcha);
        }
        // Append the script tag.
        this._renderer.appendChild(this._document?.body, script);
    }
    getUrl() {
        const baseUrl = this._config?.baseUrl ?? 'https://www.google.com/recaptcha/api.js';
        return [baseUrl, this.getQueryParams()]
            .filter(item => !!item)
            .join('?');
    }
    getQueryParams() {
        const localeId = this._localize?.current?.id ?? this._localeId ?? null;
        const params = {
            render: 'explicit',
            onload: this._windowLoadFn ?? null,
            hl: localeId
        };
        return Object.keys(params)
            .map(key => ({ key, value: params[key] }))
            .filter(item => !!item.value)
            .map(item => `${item?.key}=${item?.value}`)
            .join('&');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: RecaptchaLoader, deps: [{ token: i1.Platform }, { token: i0.RendererFactory2 }, { token: i2.Localize, optional: true }, { token: LOCALE_ID, optional: true }, { token: DOCUMENT, optional: true }, { token: RECAPTCHA_CONFIG, optional: true }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: RecaptchaLoader }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: RecaptchaLoader, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.Platform }, { type: i0.RendererFactory2 }, { type: i2.Localize, decorators: [{
                    type: Optional
                }] }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [LOCALE_ID]
                }] }, { type: Document, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [RECAPTCHA_CONFIG]
                }] }] });

let nextUniqueId = 0;
class BbRecaptchaBase {
}
const BbRecaptchaMixinBase = mixinGrouped(BbRecaptchaBase);
class RecaptchaComponent extends BbRecaptchaMixinBase {
    constructor(_zone, _platform, _renderer, _elementRef, _loader, _localizeId, _config) {
        super();
        this._zone = _zone;
        this._platform = _platform;
        this._renderer = _renderer;
        this._elementRef = _elementRef;
        this._loader = _loader;
        this._localizeId = _localizeId;
        this._config = _config;
        // Host bindings.
        this.id = `bb-recaptcha-${nextUniqueId++}`;
        // Inputs.
        this.siteKey = null;
        this.tabIndex = null;
        this.type = null;
        this.size = null;
        this.theme = null;
        this.badge = null;
        this.errorMode = 'default';
        // Outputs.
        this.resolved = new EventEmitter();
        this.error = new EventEmitter();
        // Data.
        this._widgetId = null;
        this._grecaptcha = null;
        this._executeRequested = false;
        // Form methods.
        this._onChange = null;
        this._onTouched = null;
        // Subscriptions.
        this._subscriptions = new Subscription();
        this.initializeProperties();
    }
    ngAfterViewInit() {
        this.handleOnLoad();
        this.handleLocaleChanges();
    }
    ngOnDestroy() {
        // Reset the captcha.
        this.resetCaptchaElement();
        // Unsubscribe of ready data.
        this._subscriptions?.unsubscribe();
    }
    execute() {
        // Check if the captcha is invisible.
        if (this.size !== 'invisible') {
            return;
        }
        // Check if the widget exists else return.
        if (this._widgetId == null) {
            this._executeRequested = true;
            return;
        }
        // Execute the captcha.
        this._grecaptcha.execute(this._widgetId);
    }
    reset() {
        if (this._widgetId == null) {
            return;
        }
        if (this._grecaptcha.getResponse(this._widgetId)) {
            this.resolved.emit(null);
        }
        this.resetCaptchaElement();
    }
    writeValue(value) {
        if (value) {
            return;
        }
        this.reset();
    }
    registerOnChange(fn) {
        this._onChange = fn;
    }
    registerOnTouched(fn) {
        this._onTouched = fn;
    }
    onResolve(event) {
        // Emit the value.
        this.resolved.emit(event);
        // Call the form functions.
        this._onChange?.(event);
        this._onTouched?.();
    }
    renderCaptchaElement() {
        const parameters = {
            badge: this.badge,
            sitekey: this.siteKey,
            size: this.size,
            tabindex: this.tabIndex,
            theme: this.theme,
            type: this.type,
            'callback': (response) => this._zone.run(() => this.onResolve(response)),
            'expired-callback': () => this._zone.run(() => this.onResolve(null))
        };
        if (this.errorMode === 'handled') {
            parameters['error-callback'] = (...args) => {
                return this._zone.run(() => this.error.emit(args));
            };
        }
        this._widgetId = this._grecaptcha.render(this._elementRef.nativeElement, parameters);
        if (this._executeRequested) {
            this._executeRequested = false;
            this.execute();
        }
    }
    resetCaptchaElement() {
        if (this._widgetId == null) {
            return;
        }
        this._zone.runOutsideAngular(() => this._grecaptcha.reset(this._widgetId));
    }
    initializeProperties() {
        this.siteKey = this.siteKey ?? this._config?.siteKey;
        this.theme = this.theme ?? this._config?.theme;
        this.size = this.size ?? this._config?.size;
        this.type = this.type ?? this._config?.type;
        this.badge = this.badge ?? this._config?.badge;
    }
    handleOnLoad() {
        const subscription = this._loader.ready$.subscribe((grecaptcha) => {
            if (grecaptcha == null || !(grecaptcha.render instanceof Function)) {
                return;
            }
            this._grecaptcha = grecaptcha;
            this.renderCaptchaElement();
        });
        this._subscriptions.add(subscription);
    }
    handleLocaleChanges() {
        const subscription = this._localizeId.subscribe(locale => this.onLocaleChanged(locale));
        this._subscriptions.add(subscription);
    }
    onLocaleChanged(locale) {
        const element = this._elementRef?.nativeElement ?? null;
        if (!element || !this._platform.isBrowser) {
            return;
        }
        const frame = element?.querySelector('iframe');
        if (!frame) {
            return;
        }
        const src = frame.getAttribute('src');
        const currentLanguageId = src.match(/hl=(.*?)&/).pop();
        if (currentLanguageId === locale) {
            return;
        }
        const newSrc = src.replace(/hl=(.*?)&/, `hl=${locale}&`);
        this._renderer.setAttribute(frame, 'src', newSrc);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: RecaptchaComponent, deps: [{ token: i0.NgZone }, { token: i1.Platform }, { token: i0.Renderer2 }, { token: i0.ElementRef }, { token: RecaptchaLoader }, { token: LOCALIZE_ID }, { token: RECAPTCHA_CONFIG, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.0.6", type: RecaptchaComponent, selector: "bb-recaptcha", inputs: { grouped: "grouped", id: "id", siteKey: "siteKey", tabIndex: "tabIndex", type: "type", size: "size", theme: "theme", badge: "badge", errorMode: "errorMode" }, outputs: { resolved: "resolved", error: "error" }, host: { properties: { "class.grouped": "grouped", "attr.id": "this.id" }, classAttribute: "bb-recaptcha" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => RecaptchaComponent),
                multi: true
            }
        ], exportAs: ["bbRecaptcha"], usesInheritance: true, ngImport: i0, template: "", styles: [".bb-recaptcha{display:block}.bb-recaptcha.grouped{margin-bottom:20px}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: RecaptchaComponent, decorators: [{
            type: Component,
            args: [{ selector: 'bb-recaptcha', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, exportAs: 'bbRecaptcha', providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => RecaptchaComponent),
                            multi: true
                        }
                    ], host: {
                        'class': 'bb-recaptcha',
                        '[class.grouped]': 'grouped'
                    }, inputs: ['grouped'], preserveWhitespaces: false, template: "", styles: [".bb-recaptcha{display:block}.bb-recaptcha.grouped{margin-bottom:20px}\n"] }]
        }], ctorParameters: () => [{ type: i0.NgZone }, { type: i1.Platform }, { type: i0.Renderer2 }, { type: i0.ElementRef }, { type: RecaptchaLoader }, { type: i3.Observable, decorators: [{
                    type: Inject,
                    args: [LOCALIZE_ID]
                }] }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [RECAPTCHA_CONFIG]
                }] }], propDecorators: { id: [{
                type: HostBinding,
                args: ['attr.id']
            }, {
                type: Input
            }], siteKey: [{
                type: Input
            }], tabIndex: [{
                type: Input
            }], type: [{
                type: Input
            }], size: [{
                type: Input
            }], theme: [{
                type: Input
            }], badge: [{
                type: Input
            }], errorMode: [{
                type: Input
            }], resolved: [{
                type: Output
            }], error: [{
                type: Output
            }] } });

class RecaptchaModule {
    static forRoot(config) {
        return {
            ngModule: RecaptchaModule,
            providers: [
                { provide: RECAPTCHA_CONFIG, useValue: config },
                RecaptchaLoader
            ]
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: RecaptchaModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.0.6", ngImport: i0, type: RecaptchaModule, declarations: [RecaptchaComponent], exports: [RecaptchaComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: RecaptchaModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: RecaptchaModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [RecaptchaComponent],
                    exports: [RecaptchaComponent]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RECAPTCHA_CONFIG, RecaptchaComponent, RecaptchaLoader, RecaptchaModule };
//# sourceMappingURL=bravobit-bb-foundation-recaptcha.mjs.map
