import * as i0 from '@angular/core';
import { RendererStyleFlags2, Directive, Input, NgModule } from '@angular/core';

class BbiTheming {
    // Inputs.
    set theme(theme) {
        this._theme = theme;
        this.setTheme();
    }
    constructor(_renderer, _elementRef) {
        this._renderer = _renderer;
        this._elementRef = _elementRef;
        // Cache.
        this._theme = null;
    }
    setTheme() {
        if (!this._theme) {
            return;
        }
        const variables = this._theme.variables();
        const element = this._elementRef.nativeElement;
        for (const key in variables) {
            const value = variables?.[key];
            this._renderer.setStyle(element, key, value, RendererStyleFlags2.DashCase);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbiTheming, deps: [{ token: i0.Renderer2 }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.0.6", type: BbiTheming, selector: "[bbiTheming]", inputs: { theme: ["bbiTheming", "theme"] }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: BbiTheming, decorators: [{
            type: Directive,
            args: [{
                    selector: '[bbiTheming]'
                }]
        }], ctorParameters: () => [{ type: i0.Renderer2 }, { type: i0.ElementRef }], propDecorators: { theme: [{
                type: Input,
                args: ['bbiTheming']
            }] } });

function formControlAddonThemeFactory() {
    return {
        spacing: '10px'
    };
}

function checkboxGroupThemeFactory() {
    return {
        grouping: '20px',
        label: {
            color: '#525252',
            offset: '4px',
            fontSize: '14px',
            fontWeight: '400',
            lineHeight: '1.33'
        },
        spacing: {
            horizontal: '10px',
            vertical: '4px'
        }
    };
}

class ThemeVariableFunction {
    constructor(_key) {
        this._key = _key;
    }
    toString(variables) {
        const value = variables?.[this._key] ?? null;
        if (!value) {
            throw new Error(`Invalid variable key "${this._key}"`);
        }
        return !!value ? this.format(value) : null;
    }
}
class ThemeColorVariable extends ThemeVariableFunction {
    constructor(key) {
        super(key);
        // State.
        this._opacity = 1;
    }
    format(value) {
        const rgb = this.hexToRgb(value);
        return this.toRgba(rgb);
    }
    opacity(value) {
        this._opacity = value;
        return this;
    }
    toRgba(data) {
        return `rgba(${data?.red},${data?.green},${data?.blue},${this._opacity})`;
    }
    hexToRgb(value) {
        const result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(value);
        if (!result) {
            throw new Error(`Invalid color format for "${value}". Only hex is currently supported.`);
        }
        const red = parseInt(result?.[1], 16);
        const green = parseInt(result?.[2], 16);
        const blue = parseInt(result?.[3], 16);
        return { red, green, blue };
    }
}

function controlErrorThemeFactory() {
    return {
        color: new ThemeColorVariable('errorColor'),
        fontSize: '13px',
        lineHeight: '1.5',
        fontWeight: '400',
        spacing: '4px'
    };
}

function formControlThemeFactory() {
    const errorColorKey = 'errorColor';
    const inputColor = '#111111';
    const backgroundColor = '#ffffff';
    return {
        grouping: '20px',
        color: inputColor,
        background: backgroundColor,
        error: {
            color: new ThemeColorVariable(errorColorKey),
            background: new ThemeColorVariable(errorColorKey).opacity(0.1),
            placeholderColor: new ThemeColorVariable(errorColorKey).opacity(0.4)
        },
        border: {
            radius: '6px',
            width: '1px',
            style: 'solid',
            color: 'rgba(67, 90, 111, 0.3)'
        },
        focused: {
            color: inputColor,
            background: backgroundColor,
            border: {
                radius: '6px',
                width: '1px',
                style: 'solid',
                color: '#212121'
            },
            shadow: '0 0 0 3px rgba(0, 123, 255, 0.2)'
        },
        disabled: {
            color: inputColor,
            background: backgroundColor,
            border: {
                radius: '6px',
                width: '1px',
                style: 'solid',
                color: '#212121'
            },
            opacity: '0.25'
        }
    };
}

function toggleGroupThemeFactory() {
    return {
        grouping: '20px',
        label: {
            color: '#525252',
            offset: '4px',
            fontSize: '14px',
            fontWeight: '400',
            lineHeight: '1.33'
        },
        spacing: {
            horizontal: '10px',
            vertical: '4px'
        }
    };
}

function radioButtonThemeFactory() {
    const accentColor = new ThemeColorVariable('accentColor');
    return {
        size: '20px',
        colors: {
            accent: accentColor,
            disabled: '#c6c6c6'
        },
        border: {
            color: '#111111',
            thickness: '1px',
            radius: '50%'
        },
        outline: {
            color: accentColor,
            offset: '1px',
            thickness: '2px'
        },
        label: {
            color: '#111111',
            offset: '6px',
            fontSize: '16px',
            fontWeight: '400',
            lineHeight: '1.28'
        }
    };
}

function radioGroupThemeFactory() {
    const errorColor = new ThemeColorVariable('errorColor');
    return {
        grouping: '20px',
        error: errorColor,
        label: {
            color: '#525252',
            offset: '4px',
            fontSize: '14px',
            fontWeight: '400',
            lineHeight: '1.33'
        },
        spacing: {
            horizontal: '10px',
            vertical: '4px'
        }
    };
}

function checkboxThemeFactory() {
    const accentColor = new ThemeColorVariable('accentColor');
    return {
        size: '20px',
        grouping: '20px',
        colors: {
            accent: accentColor,
            disabled: '#c6c6c6'
        },
        border: {
            color: '#111111',
            thickness: '1px',
            radius: '4px'
        },
        outline: {
            color: accentColor,
            offset: '1px',
            thickness: '2px'
        },
        check: {
            size: '12px',
            color: 'white',
            thickness: '2px'
        },
        label: {
            color: '#111111',
            offset: '6px',
            fontSize: '16px',
            fontWeight: '400',
            lineHeight: '1.28'
        }
    };
}

function toggleThemeFactory() {
    const accentColor = new ThemeColorVariable('accentColor');
    return {
        grouping: '20px',
        width: '40px',
        height: '20px',
        colors: {
            accent: accentColor,
            disabled: '#c6c6c6',
            indicator: '#ffffff',
            background: '#aeaeae'
        },
        outline: {
            color: accentColor,
            offset: '1px',
            thickness: '2px'
        },
        label: {
            color: '#111111',
            offset: '6px',
            fontSize: '16px',
            fontWeight: '400',
            lineHeight: '1.28'
        }
    };
}

class Theme {
    constructor(theme) {
        this.isObject = (item) => {
            return (item && typeof item === 'object' && !Array.isArray(item));
        };
        const defaultFactories = this.defaultFactories();
        this.data = this.mergeThemeData(defaultFactories, theme);
        this.globals = this.getGlobals();
    }
    variables() {
        return this.getContents(this.data);
    }
    defaultFactories() {
        return {
            accentColor: '#1565c0',
            errorColor: '#bd322a',
            formControl: formControlThemeFactory(),
            formControlAddon: formControlAddonThemeFactory(),
            checkbox: checkboxThemeFactory(),
            checkboxGroup: checkboxGroupThemeFactory(),
            radioButton: radioButtonThemeFactory(),
            radioGroup: radioGroupThemeFactory(),
            toggle: toggleThemeFactory(),
            toggleGroup: toggleGroupThemeFactory(),
            controlError: controlErrorThemeFactory()
        };
    }
    getContents(data, scope = null) {
        return Object.keys(data).reduce((previous, current) => {
            const value = data?.[current];
            const token = this.getToken(current, scope);
            if (typeof value === 'object' && value !== null && !(value instanceof ThemeVariableFunction)) {
                const formatted = this.getContents(value, token);
                return { ...previous, ...formatted };
            }
            const formattedValue = (value instanceof ThemeVariableFunction)
                ? value.toString(this.globals)
                : value;
            if (!formattedValue) {
                return previous;
            }
            return { ...previous, [`--${token}`]: formattedValue };
        }, {});
    }
    getToken(key, scope) {
        const token = this.tokenize(key);
        return [scope, token].filter(item => !!item).join('-');
    }
    tokenize(value) {
        const result = value.replace(/([A-Z])/g, ' $1');
        return result.split(' ').join('-').toLowerCase();
    }
    mergeThemeData(target, ...sources) {
        if (!sources?.length) {
            return target;
        }
        const source = sources.shift();
        if (this.isObject(target) && this.isObject(source)) {
            for (const key in source) {
                if (this.isObject(source[key])) {
                    if (!target[key]) {
                        Object.assign(target, { [key]: {} });
                    }
                    this.mergeThemeData(target[key], source[key]);
                }
                else {
                    Object.assign(target, { [key]: source[key] });
                }
            }
        }
        return this.mergeThemeData(target, ...sources);
    }
    getGlobals() {
        return {
            accentColor: this.data.accentColor,
            errorColor: this.data.errorColor
        };
    }
}

class ThemingModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: ThemingModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.0.6", ngImport: i0, type: ThemingModule, declarations: [BbiTheming], exports: [BbiTheming] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: ThemingModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: ThemingModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [BbiTheming],
                    exports: [BbiTheming]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BbiTheming, Theme, ThemeColorVariable, ThemeVariableFunction, ThemingModule, checkboxGroupThemeFactory, checkboxThemeFactory, formControlAddonThemeFactory, formControlThemeFactory };
//# sourceMappingURL=bravobit-bb-foundation-theming.mjs.map
