import * as i0 from '@angular/core';
import { InjectionToken, Component, ChangeDetectionStrategy, ViewEncapsulation, Inject, HostBinding, Injector, Directive, Input, HostListener, NgModule } from '@angular/core';
import * as i1 from '@bravobit/bb-foundation/utils';
import { UtilsModule } from '@bravobit/bb-foundation/utils';
import { coerceBooleanProperty } from '@angular/cdk/coercion';
import { ComponentPortal } from '@angular/cdk/portal';
import * as i1$1 from '@angular/cdk/overlay';
import { OverlayModule } from '@angular/cdk/overlay';

const TOOLTIP_DATA = new InjectionToken('Data to display in tooltip');
const TOOLTIP_CLASS = new InjectionToken('Class to display in tooltip');

class TooltipContainerComponent {
    constructor(data, classes) {
        this.data = data;
        this.classes = classes;
    }
    get classBinding() {
        return [this.classes]
            .filter(item => !!item)
            .join(' ');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: TooltipContainerComponent, deps: [{ token: TOOLTIP_DATA }, { token: TOOLTIP_CLASS }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.0.6", type: TooltipContainerComponent, selector: "bb-tooltip-container", host: { properties: { "class": "this.classBinding" }, classAttribute: "bb-tooltip-container" }, ngImport: i0, template: "<ng-template [bbTemplate]=\"data\">\n    {{ data }}\n</ng-template>\n", styles: [".bb-tooltip-container{color:#fff;display:block;font-size:14px;max-width:400px;padding:8px 10px;-webkit-user-select:none;user-select:none;position:relative;border-radius:4px;pointer-events:none;-webkit-backdrop-filter:blur(20px);backdrop-filter:blur(20px);background-color:#111111e6}.bb-tooltip-container:after{width:0;height:0;content:\"\";display:block;position:absolute;border-style:solid;-webkit-backdrop-filter:blur(20px);backdrop-filter:blur(20px)}.bb-tooltip-container>small{display:block;font-size:12px;margin-top:4px;color:#fff6}.bb-tooltip-container-bottom,.bb-tooltip-container-top,.bb-tooltip-container-left,.bb-tooltip-container-right{pointer-events:none}.bb-tooltip-container-top .bb-tooltip-container:after{left:50%;top:100%;transform:translate(-50%);border-width:6px 6px 0 6px;border-color:rgba(17,17,17,.9) transparent transparent transparent}.bb-tooltip-container-bottom .bb-tooltip-container:after{left:50%;bottom:100%;transform:translate(-50%);border-width:0 6px 6px 6px;border-color:transparent transparent rgba(17,17,17,.9) transparent}.bb-tooltip-container-left .bb-tooltip-container:after{top:50%;left:100%;transform:translateY(-50%);border-width:6px 0 6px 6px;border-color:transparent transparent transparent rgba(17,17,17,.9)}.bb-tooltip-container-right .bb-tooltip-container:after{top:50%;right:100%;transform:translateY(-50%);border-width:6px 6px 6px 0;border-color:transparent rgba(17,17,17,.9) transparent transparent}\n"], dependencies: [{ kind: "directive", type: i1.BbTemplate, selector: "[bbTemplate]", inputs: ["bbTemplate"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: TooltipContainerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'bb-tooltip-container', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, host: { 'class': 'bb-tooltip-container' }, preserveWhitespaces: false, template: "<ng-template [bbTemplate]=\"data\">\n    {{ data }}\n</ng-template>\n", styles: [".bb-tooltip-container{color:#fff;display:block;font-size:14px;max-width:400px;padding:8px 10px;-webkit-user-select:none;user-select:none;position:relative;border-radius:4px;pointer-events:none;-webkit-backdrop-filter:blur(20px);backdrop-filter:blur(20px);background-color:#111111e6}.bb-tooltip-container:after{width:0;height:0;content:\"\";display:block;position:absolute;border-style:solid;-webkit-backdrop-filter:blur(20px);backdrop-filter:blur(20px)}.bb-tooltip-container>small{display:block;font-size:12px;margin-top:4px;color:#fff6}.bb-tooltip-container-bottom,.bb-tooltip-container-top,.bb-tooltip-container-left,.bb-tooltip-container-right{pointer-events:none}.bb-tooltip-container-top .bb-tooltip-container:after{left:50%;top:100%;transform:translate(-50%);border-width:6px 6px 0 6px;border-color:rgba(17,17,17,.9) transparent transparent transparent}.bb-tooltip-container-bottom .bb-tooltip-container:after{left:50%;bottom:100%;transform:translate(-50%);border-width:0 6px 6px 6px;border-color:transparent transparent rgba(17,17,17,.9) transparent}.bb-tooltip-container-left .bb-tooltip-container:after{top:50%;left:100%;transform:translateY(-50%);border-width:6px 0 6px 6px;border-color:transparent transparent transparent rgba(17,17,17,.9)}.bb-tooltip-container-right .bb-tooltip-container:after{top:50%;right:100%;transform:translateY(-50%);border-width:6px 6px 6px 0;border-color:transparent rgba(17,17,17,.9) transparent transparent}\n"] }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [TOOLTIP_DATA]
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [TOOLTIP_CLASS]
                }] }], propDecorators: { classBinding: [{
                type: HostBinding,
                args: ['class']
            }] } });

class TooltipDirective {
    // Disabled.
    get bbTooltipDisabled() {
        return this._bbTooltipDisabled;
    }
    set bbTooltipDisabled(value) {
        const newValue = coerceBooleanProperty(value);
        if (newValue !== this.bbTooltipDisabled) {
            this._bbTooltipDisabled = newValue;
            this._changeDetectorRef.markForCheck();
        }
    }
    constructor(_overlay, _viewContainer, _elementRef, _changeDetectorRef) {
        this._overlay = _overlay;
        this._viewContainer = _viewContainer;
        this._elementRef = _elementRef;
        this._changeDetectorRef = _changeDetectorRef;
        this.bbTooltipClass = null;
        this.bbTooltipOrigin = null;
        this.bbTooltipPositions = [];
        this._bbTooltipDisabled = false;
        // State.
        this._overlayRef = null;
    }
    showTooltip() {
        if (this._overlayRef?.hasAttached() || this.bbTooltipDisabled) {
            return;
        }
        this.attachTooltip();
    }
    hideTooltip() {
        if (!this._overlayRef?.hasAttached()) {
            return;
        }
        this._overlayRef?.detach();
    }
    ngOnDestroy() {
        this._overlayRef?.dispose();
    }
    attachTooltip() {
        if (this._overlayRef === null) {
            const positionStrategy = this.getPositionStrategy();
            const scrollStrategy = this._overlay.scrollStrategies.reposition();
            this._overlayRef = this._overlay.create({ positionStrategy, scrollStrategy });
        }
        const injector = Injector.create({
            providers: [
                { provide: TOOLTIP_DATA, useValue: this.bbTooltip },
                { provide: TOOLTIP_CLASS, useValue: this.bbTooltipClass }
            ]
        });
        const component = new ComponentPortal(TooltipContainerComponent, this._viewContainer, injector);
        this._overlayRef.attach(component);
    }
    getPositionStrategy() {
        const element = this.bbTooltipOrigin ?? this._elementRef;
        const positions = this.getPositions();
        return this._overlay
            .position()
            .flexibleConnectedTo(element)
            .withPositions(positions);
    }
    getPositions() {
        if (this.bbTooltipPositions?.length > 0) {
            return this.bbTooltipPositions;
        }
        return [
            {
                originX: 'center',
                originY: 'top',
                overlayX: 'center',
                overlayY: 'bottom',
                offsetY: -10,
                panelClass: 'bb-tooltip-container-top'
            },
            {
                originX: 'center',
                originY: 'bottom',
                overlayX: 'center',
                overlayY: 'top',
                offsetY: 10,
                panelClass: 'bb-tooltip-container-bottom'
            },
            {
                originX: 'start',
                originY: 'center',
                overlayX: 'end',
                overlayY: 'center',
                offsetX: -10,
                panelClass: 'bb-tooltip-container-left'
            },
            {
                originX: 'end',
                originY: 'center',
                overlayX: 'start',
                overlayY: 'center',
                offsetX: 10,
                panelClass: 'bb-tooltip-container-right'
            }
        ];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: TooltipDirective, deps: [{ token: i1$1.Overlay }, { token: i0.ViewContainerRef }, { token: i0.ElementRef }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.0.6", type: TooltipDirective, selector: "[bbTooltip]", inputs: { bbTooltip: "bbTooltip", bbTooltipClass: "bbTooltipClass", bbTooltipOrigin: "bbTooltipOrigin", bbTooltipPositions: "bbTooltipPositions", bbTooltipDisabled: "bbTooltipDisabled" }, host: { listeners: { "mouseenter": "showTooltip()", "focus": "showTooltip()", "mouseleave": "hideTooltip()", "blur": "hideTooltip()" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: TooltipDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[bbTooltip]'
                }]
        }], ctorParameters: () => [{ type: i1$1.Overlay }, { type: i0.ViewContainerRef }, { type: i0.ElementRef }, { type: i0.ChangeDetectorRef }], propDecorators: { bbTooltip: [{
                type: Input
            }], bbTooltipClass: [{
                type: Input
            }], bbTooltipOrigin: [{
                type: Input
            }], bbTooltipPositions: [{
                type: Input
            }], bbTooltipDisabled: [{
                type: Input
            }], showTooltip: [{
                type: HostListener,
                args: ['mouseenter']
            }, {
                type: HostListener,
                args: ['focus']
            }], hideTooltip: [{
                type: HostListener,
                args: ['mouseleave']
            }, {
                type: HostListener,
                args: ['blur']
            }] } });

class TooltipModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: TooltipModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.0.6", ngImport: i0, type: TooltipModule, declarations: [TooltipContainerComponent,
            TooltipDirective], imports: [UtilsModule,
            OverlayModule], exports: [TooltipDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: TooltipModule, imports: [UtilsModule,
            OverlayModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.6", ngImport: i0, type: TooltipModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        UtilsModule,
                        OverlayModule
                    ],
                    declarations: [
                        TooltipContainerComponent,
                        TooltipDirective
                    ],
                    exports: [
                        TooltipDirective
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { TOOLTIP_CLASS, TOOLTIP_DATA, TooltipContainerComponent, TooltipDirective, TooltipModule };
//# sourceMappingURL=bravobit-bb-foundation-tooltip.mjs.map
